# 🔑 获取 Supabase API 密钥指南

## ❌ 当前问题
你遇到了 "Invalid API key" 错误，这是因为配置文件中的 API 密钥不正确或已过期。

## 🔧 解决步骤

### 1. 访问 Supabase 控制台
```
https://supabase.com/dashboard/project/poxwjzdianersitpnvdy
```

### 2. 获取 API 密钥
1. 在项目控制台中，点击左侧菜单的 **"Settings"**
2. 选择 **"API"** 选项
3. 在 **"Project API keys"** 部分找到：
   - **anon public** 密钥（这是我们需要的）
   - **service_role** 密钥（用于服务端操作）

### 3. 更新配置文件
复制 **anon public** 密钥，然后更新 `web-app/config.js` 文件：

```javascript
// 应用配置文件
const CONFIG = {
    // Supabase 配置 - Twilio-project
    SUPABASE: {
        URL: 'https://poxwjzdianersitpnvdy.supabase.co',
        ANON_KEY: '你的_anon_public_密钥_在这里'  // 替换为实际密钥
    },
    // ... 其他配置保持不变
};
```

### 4. 验证连接
更新密钥后：
1. 刷新浏览器页面
2. 尝试重新注册用户
3. 检查浏览器控制台是否还有错误

## 🚨 重要提示

- **不要分享 service_role 密钥**：这个密钥有完全的数据库访问权限
- **anon public 密钥是安全的**：可以在前端代码中使用
- **检查密钥格式**：应该是以 `eyJ` 开头的长字符串

## 🔍 常见问题

### Q: 找不到 API 密钥？
A: 确保你已经登录到正确的 Supabase 账户，并且有访问该项目的权限。

### Q: 密钥看起来正确但仍然报错？
A: 检查项目状态是否为 "Active"，并且确保没有复制错误（没有额外的空格或字符）。

### Q: 如何知道密钥是否正确？
A: 正确的 anon public 密钥应该：
- 以 `eyJ` 开头
- 包含三个部分，用 `.` 分隔
- 长度通常在 100-200 个字符之间

## 📞 需要帮助？
如果你仍然遇到问题，请：
1. 确认你能正常访问 Supabase 控制台
2. 检查项目状态是否正常
3. 确保复制的密钥完整且正确 